<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}

$opt_name = kimono()->get_option_name();
$version = kimono()->get_version();

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => '', //$theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $version,
    // Version that appears at the top of your panel
    'menu_type'            => 'submenu', //class_exists('Pxltheme_Core') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'kimono'),
    'page_title'           => esc_html__('Theme Options', 'kimono'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => true,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    'show_options_object' => false,
    // OPTIONAL -> Give you extra features
    'page_priority'        => 80,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'pxlart', //class_exists('Kimono_Admin_Page') ? 'case' : '',
    // For a full list of options, visit: //codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'pxlart-theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    ),
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'kimono'),
    'icon'   => 'el-icon-home',
    'fields' => array(
        array(
            'id'       => 'favicon',
            'type'     => 'media',
            'title'    => esc_html__('Favicon', 'kimono'),
            'default'  => '',
            'url'      => false
        ),
        array(
            'id'       => 'mouse_move_animation',
            'type'     => 'switch',
            'title'    => esc_html__('Mouse Move Animation', 'kimono'),
            'default'  => false
        ),
        array(
            'id'       => 'page_lading',
            'title'    => esc_html__('Page Loading', 'kimono'),
            'type'     => 'section',
            'indent'   => true,
        ),
        array(
            'id'       => 'site_loader',
            'type'     => 'switch',
            'title'    => esc_html__('Loader', 'kimono'),
            'default'  => false
        ),
        array(
            'id'       => 'loader_style',
            'type'     => 'select',
            'title'    => esc_html__('Loader Style', 'kimono'),
            'options'  => [
                'style-text'           => esc_html__('Text', 'kimono'),
                'style-text-blend'     => esc_html__('Text Blend', 'kimono'),
                'style-triangle'       => esc_html__('Triangle', 'kimono'),
                'style-home-assistant' => esc_html__('Home Assistant', 'kimono'),
            ],
            'default'  => 'style-text',
            'indent'   => true,
            'required' => array( 0 => 'site_loader', 1 => 'equals', 2 => true ),
        ),
        array(
            'id'             => 'loading_text',
            'type'           => 'text',
            'title'          => esc_html__('Loading Text', 'kimono'),
            'default'        => '',
            'desc'           => esc_html__('Enter the text displayed on load.', 'kimono'),
            'required'       => array( 0 => 'loader_style', 1 => 'equals', 2 => array('loader_style', 'style-text-blend') ),
            'force_output'   => true
        ),
        array(
            'id'       => 'loader_logo',
            'type'     => 'media',
            'title'    => esc_html__('Logo', 'kimono'),
            'url'      => false,
            'required' => array( 0 => 'loader_style', 1 => 'equals', 2 => array('loader_style', 'style-home-assistant') ),
        ),
        array(
            'id'       => 'loader_logo_height',
            'type'     => 'dimensions',
            'title'    => esc_html__('Logo Height', 'kimono'),
            'width'    => false,
            'unit'     => 'px',
            'output'    => array('.pxl-loader .loader-logo img'),
            'required' => array( 0 => 'loader_style', 1 => 'equals', 2 => array('loader_style', 'style-home-assistant') ),
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Smooth Scroll', 'kimono'),
    'icon'       => 'el el-circle-arrow-right',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'smooth_scroll',
            'type'     => 'button_set',
            'title'    => esc_html__('Smooth Scroll', 'kimono'),
            'options'  => array(
                'on' => esc_html__('On', 'kimono'),
                'off' => esc_html__('Off', 'kimono'),
            ),
            'default'  => 'off',
        ),
    )
));

/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Colors', 'kimono'),
    'icon'   => 'el-icon-file-edit',
    'fields' => array(
        array(
            'id'       => 'button_light_dark_on',
            'type'     => 'switch',
            'title'    => esc_html__('Button Switch Light/Dark', 'kimono'),
            'default'  => false,
        ),
        array(
            'id'       => 'light_dark_switch',
            'type'     => 'button_set',
            'title'    => esc_html__('Color Mode', 'kimono'),
            'options'  => array(
                'pxl-light-mode' => esc_html__('Light Layous', 'kimono'),
                'pxl-dark-mode'  => esc_html__('Dark Layous', 'kimono'),
            ),
            'default'  => 'pxl-dark-mode',
        ),
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'secondary_color',
            'type'        => 'color',
            'title'       => esc_html__('Secondary Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'third_color',
            'type'        => 'color',
            'title'       => esc_html__('Third Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'fourth_color',
            'type'        => 'color',
            'title'       => esc_html__('Fourth Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'fifth_color',
            'type'        => 'color',
            'title'       => esc_html__('Fifth Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'sixth_color',
            'type'        => 'color',
            'title'       => esc_html__('Sixth Color', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'      => 'link_color',
            'type'    => 'link_color',
            'title'   => esc_html__('Link Colors', 'kimono'),
            'default' => array(
                'regular' => '',
                'hover'   => '',
                'active'  => ''
            ),
            'output'  => array('a')
        ),
        array(
            'id'          => 'gradient_color',
            'type'        => 'color_gradient',
            'title'       => esc_html__('Gradient Color', 'kimono'),
            'transparent' => false,
            'default'  => array(
                'from' => '',
                'to'   => '', 
            ),
        ),
        array(
            'id'          => 'bg_light_color',
            'type'        => 'color',
            'title'       => esc_html__('Background Color - Light', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'bg_dark_color',
            'type'        => 'color',
            'title'       => esc_html__('Background Color - Dark', 'kimono'),
            'transparent' => false,
            'default'     => ''
        ),
    )
));

/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Header', 'kimono'),
    'icon'   => 'el el-indent-left',
    'fields' => array_merge(
        kimono_header_opts(),
        array(
            array(
                'id'       => 'sticky_scroll',
                'type'     => 'button_set',
                'title'    => esc_html__('Sticky Scroll', 'kimono'),
                'options'  => array(
                    'pxl-sticky-stt' => esc_html__('Scroll To Top', 'kimono'),
                    'pxl-sticky-stb'  => esc_html__('Scroll To Bottom', 'kimono'),
                ),
                'default'  => 'pxl-sticky-stb',
            ),
        )
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Mobile', 'kimono'),
    'icon'       => 'el el-picture',
    'subsection' => true,
    'fields'     => array_merge(
        kimono_header_mobile_opts(),
        array(
            array(
                'id'       => 'logo_m',
                'type'     => 'media',
                'title'    => esc_html__('Logo Light', 'kimono'),
                'default' => array(
                    'url'=>get_template_directory_uri().'/assets/img/logo-light.png'
                ),
                'url'      => false
            ),
            array(
                'id'       => 'logo_m_dark',
                'type'     => 'media',
                'title'    => esc_html__('Logo Dark', 'kimono'),
                'default' => array(
                    'url'=>get_template_directory_uri().'/assets/img/logo-dark.png'
                ),
                'url'      => false
            ),
            array(
                'id'       => 'logo_height',
                'type'     => 'dimensions',
                'title'    => esc_html__('Logo Height', 'kimono'),
                'width'    => false,
                'unit'     => 'px',
                'output'    => array('#pxl-header-default .pxl-header-branding img, .pxl-logo-mobile img'),
            ),
            array(
                'id'       => 'search_mobile',
                'type'     => 'switch',
                'title'    => esc_html__('Search Form', 'kimono'),
                'default'  => true
            ),
            array(
                'id'       => 'header_fixed',
                'type'     => 'switch',
                'title'    => esc_html__('Header Fixed', 'kimono'),
                'default'  => false,
            )
        )
    )
));

/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Page Title', 'kimono'),
    'icon'   => 'el-icon-map-marker',
    'fields' => array_merge(
        kimono_page_title_opts()        
    )
));


/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('Footer', 'kimono'),
    'icon'   => 'el el-website',
    'fields' => array_merge(
        kimono_footer_opts(),
        array(
            array(
                'id'       => 'back_totop_on',
                'type'     => 'switch',
                'title'    => esc_html__('Button Back to Top', 'kimono'),
                'default'  => false,
            ),
            array(
                'id'       => 'back_totop_text',
                'type'     => 'text',
                'title'    => esc_html__('Back To Top Text', 'kimono'),
                'placeholder' => esc_html__('UP', 'kimono' ),
                'required' => array( 0 => 'back_totop_on', 1 => 'equals', 2 => '1' ),
            ),
            array(
                'id'       => 'footer_fixed',
                'type'     => 'switch',
                'title'    => esc_html__('Footer Fixed', 'kimono'),
                'default'  => false,
            )
        )
    )

));

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title' => esc_html__('Blog Archive', 'kimono'),
    'icon'  => 'el-icon-pencil',
    'fields'     => array_merge(
        kimono_sidebar_pos_opts([ 'prefix' => 'blog_']),
        array(
            array(
                'id'       => 'archive_date',
                'title'    => esc_html__('Date', 'kimono'),
                'subtitle' => esc_html__('Display the Date for each blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true,
            ),
            array(
                'id'       => 'archive_author',
                'title'    => esc_html__('Author', 'kimono'),
                'subtitle' => esc_html__('Display the Author for each blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true,
            ),
            array(
                'id'       => 'archive_excerpts',
                'title'    => esc_html__('Excerpt', 'kimono'),
                'subtitle' => esc_html__('Show Excerpt for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => false
            ),
            array(
                'id'      => 'archive_excerpt_length',
                'type'    => 'text',
                'title'   => esc_html__('Excerpt Length', 'kimono'),
                'default' => '',
                'subtitle' => esc_html__('Default: 50', 'kimono'),
                'required' => array( 0 => 'archive_excerpts', 1 => 'equals', 2 => '1' ),
            )
        )
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Post', 'kimono'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array_merge(
        kimono_sidebar_pos_opts([ 'prefix' => 'post_']),
        array(
            array(
                'id'       => 'sg_post_title',
                'type'     => 'button_set',
                'title'    => esc_html__('Page Title Type', 'kimono'),
                'options'  => array(
                    'default' => esc_html__('Default', 'kimono'),
                    'custom_text' => esc_html__('Custom Text', 'kimono'),
                ),
                'default'  => 'default',
            ),
            array(
                'id'      => 'sg_post_title_text',
                'type'    => 'text',
                'title'   => esc_html__('Page Title Text', 'kimono'),
                'default' => 'Blog Details',
                'required' => array( 0 => 'sg_post_title', 1 => 'equals', 2 => 'custom_text' ),
            ),
            array(
                'id'       => 'post_title',
                'title'    => esc_html__('Title', 'kimono'),
                'subtitle' => esc_html__('Show Title on single post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'id'       => 'post_date',
                'title'    => esc_html__('Date', 'kimono'),
                'subtitle' => esc_html__('Display the Date for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'id'       => 'post_author',
                'title'    => esc_html__('Author', 'kimono'),
                'subtitle' => esc_html__('Display the Author for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'id'       => 'post_comment',
                'title'    => esc_html__('Comment Count', 'kimono'),
                'subtitle' => esc_html__('Display the Comment for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'id'       => 'post_view',
                'title'    => esc_html__('View Count', 'kimono'),
                'subtitle' => esc_html__('Display the View for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => true
            ),
            array(
                'id' => 'social_section',
                'title' => esc_html__('Social', 'kimono'),
                'type'  => 'section',
                'indent' => true,
            ),
            array(
                'id'       => 'post_social_share',
                'title'    => esc_html__('Social', 'kimono'),
                'subtitle' => esc_html__('Display the Social Share for blog post.', 'kimono'),
                'type'     => 'switch',
                'default'  => false,
            ),
            array(
                'id'       => 'social_facebook',
                'title'    => esc_html__('Facebook', 'kimono'),
                'type'     => 'switch',
                'default'  => false,
                'indent' => true,
                'required' => array( 0 => 'post_social_share', 1 => 'equals', 2 => '1' ),
            ),
            array(
                'id'       => 'social_twitter',
                'title'    => esc_html__('Twitter', 'kimono'),
                'type'     => 'switch',
                'default'  => false,
                'indent' => true,
                'required' => array( 0 => 'post_social_share', 1 => 'equals', 2 => '1' ),
            ),
            array(
                'id'       => 'social_pinterest',
                'title'    => esc_html__('Pinterest', 'kimono'),
                'type'     => 'switch',
                'default'  => false,
                'indent' => true,
                'required' => array( 0 => 'post_social_share', 1 => 'equals', 2 => '1' ),
            ),
            array(
                'id'       => 'social_linkedin',
                'title'    => esc_html__('LinkedIn', 'kimono'),
                'type'     => 'switch',
                'default'  => false,
                'indent' => true,
                'required' => array( 0 => 'post_social_share', 1 => 'equals', 2 => '1' ),
            ),
        )
)
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Extra Post Type', 'kimono'),
    'icon'       => 'el el-briefcase',
    'fields'     => array(
        array(
            'title' => esc_html__('Service', 'kimono'),
            'type'  => 'section',
            'id' => 'post_service',
            'indent' => true,
        ),
        array(
            'id'      => 'service_slug',
            'type'    => 'text',
            'title'   => esc_html__('Service Slug', 'kimono'),
            'default' => '',
            'desc'     => 'Default: service',
        ),
        array(
            'id'      => 'service_name',
            'type'    => 'text',
            'title'   => esc_html__('Service Name', 'kimono'),
            'default' => '',
            'desc'     => 'Default: Service',
        ),
        array(
            'id'      => 'service_category_slug',
            'type'    => 'text',
            'title'   => esc_html__('Service Category Slug', 'kimono'),
            'default' => '',
            'desc'     => 'Default: service-category',
        ),
        array(
            'id'      => 'service_category_name',
            'type'    => 'text',
            'title'   => esc_html__('Service Category Name', 'kimono'),
            'default' => '',
            'desc'     => 'Default: Service Categories',
        ),
        array(
            'id'    => 'archive_service_link',
            'type'  => 'select',
            'title' => esc_html__( 'Custom Archive Page Link', 'kimono' ),
            'data'  => 'page',
            'args'  => array(
                'post_type'      => 'page',
                'posts_per_page' => -1,
                'orderby'        => 'title',
                'order'          => 'ASC',
            ),
        ),
    )
));

Redux::setSection($opt_name, array(
    'title'      => esc_html__('Post Type Portfolio', 'kimono'),
    'icon'       => 'el el-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'title' => esc_html__('Portfolio', 'kimono'),
            'type'  => 'section',
            'id' => 'post_portfolio',
            'indent' => true,
        ),
        array(
            'id'       => 'portfolio_navigation',
            'title'    => esc_html__('Navigation', 'kimono'),
            'subtitle' => esc_html__('Display the Navigation for portfolio post.', 'kimono'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'portfolio_nav_link',
            'type'     => 'text',
            'title'    => esc_html__('Navigation Button Link', 'kimono'),
            'subtitle' => esc_html__('Enter navigation middle button link.', 'kimono'),
            'default'  => '#',
            'required' => array( 0 => 'portfolio_navigation', 1 => 'equals', 2 => '1' ),
        ),
        array(
            'id'       => 'portfolio_nav_text',
            'type'     => 'text',
            'title'    => esc_html__('Text caption', 'kimono'),
            'subtitle' => esc_html__('Text caption middle button link on hover.', 'kimono'),
            'placeholder' => esc_html__('Show All Projects', 'kimono' ),
            'required' => array( 0 => 'portfolio_navigation', 1 => 'equals', 2 => '1' ),
        ),
        array(
            'id'       => 'projects_related',
            'title'    => esc_html__('Related Projects', 'kimono'),
            'subtitle' => esc_html__('Show Related Projects for portfolio post.', 'kimono'),
            'type'     => 'switch',
            'default'  => false,
        ),
        array(
            'id'       => 'projects_related_title',
            'type'     => 'text',
            'title'    => esc_html__('Related Projects Title Text', 'kimono'),
            'placeholder' => esc_html__('PROJECT CONCEPT', 'kimono' ),
            'required' => array( 0 => 'projects_related', 1 => 'equals', 2 => '1' ),
        ),
        array(
            'id'      => 'portfolio_slug',
            'type'    => 'text',
            'title'   => esc_html__('Portfolio Slug', 'kimono'),
            'default' => '',
            'desc'     => 'Default: portfolio',
        ),
        array(
            'id'      => 'portfolio_name',
            'type'    => 'text',
            'title'   => esc_html__('Portfolio Name', 'kimono'),
            'default' => '',
            'desc'     => 'Default: Portfolio',
        ),
        array(
            'id'      => 'portfolio_category_slug',
            'type'    => 'text',
            'title'   => esc_html__('Portfolio Category Slug', 'kimono'),
            'default' => '',
            'desc'     => 'Default: portfolio-category',
        ),
        array(
            'id'      => 'portfolio_category_name',
            'type'    => 'text',
            'title'   => esc_html__('Portfolio Category Name', 'kimono'),
            'default' => '',
            'desc'     => 'Default: Portfolio Categories',
        ),
        array(
            'id'    => 'archive_portfolio_link',
            'type'  => 'select',
            'title' => esc_html__( 'Custom Archive Page Link', 'kimono' ),
            'data'  => 'page',
            'args'  => array(
                'post_type'      => 'page',
                'posts_per_page' => -1,
                'orderby'        => 'title',
                'order'          => 'ASC',
            ),
        ),
    )
));

/*--------------------------------------------------------------
# Woocommerce
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title' => esc_html__('Woocommerce', 'kimono'),
        'icon'  => 'el el-shopping-cart',
        'fields'     => array_merge(
            kimono_sidebar_pos_opts([ 'prefix' => 'shop_']),
            array(
                array(
                    'title'         => esc_html__('Products displayed per row', 'kimono'),
                    'id'            => 'products_columns',
                    'type'          => 'slider',
                    'subtitle'      => esc_html__('Number product to show per row', 'kimono'),
                    'default'       => 4,
                    'min'           => 2,
                    'step'          => 1,
                    'max'           => 6,
                    'display_value' => 'text'
                ),
                array(
                    'title'         => esc_html__('Products displayed per page', 'kimono'),
                    'id'            => 'product_per_page',
                    'type'          => 'slider',
                    'subtitle'      => esc_html__('Number product to show', 'kimono'),
                    'default'       => 12,
                    'min'           => 3,
                    'step'          => 1,
                    'max'           => 50,
                    'display_value' => 'text'
                ),
            ),
            kimono_shop_opts()
        )
    ));

    Redux::setSection($opt_name, array(
        'title'      => esc_html__('Single Product', 'kimono'),
        'icon'       => 'el el-shopping-cart',
        'subsection' => true,
        'fields'     => array_merge(
            kimono_sidebar_pos_opts([ 'prefix' => 'product_']),
            array(
                array(
                    'id'       => 'product_title',
                    'type'     => 'switch',
                    'title'    => esc_html__('Product Title', 'kimono'),
                    'default'  => true
                ),
                array(
                    'id'       => 'product_social_share',
                    'type'     => 'switch',
                    'title'    => esc_html__('Social Share', 'kimono'),
                    'default'  => false
                ),
                array(
                    'id'       => 'product_related',
                    'title'    => esc_html__('Product Related', 'kimono'),
                    'subtitle' => esc_html__('Show/Hide related product', 'kimono'),
                    'type'     => 'switch',
                    'default'  => '1',
                ),
                array(
                    'id'      => 'product_related_title',
                    'type'    => 'text',
                    'title'   => esc_html__('Related Title', 'kimono'),
                    'default' => '',
                    'placeholder' => esc_html__('Related Products', 'kimono'),
                    'required' => array( 0 => 'product_related', 1 => 'equals', 2 => '1' ),
                ),
                array(
                    'id'       => 'product_variation_style',
                    'type'     => 'button_set',
                    'title'    => esc_html__('Product Variation Style', 'kimono'),
                    'subtitle' => esc_html__('Dropdown or selected list', 'kimono'),
                    'options' => array(
                        'dropdown'  => esc_html__('Dropdown', 'kimono'),
                        'list' => esc_html__('List', 'kimono')
                    ),
                    'default' => 'dropdown'
                ),
            ),
            kimono_shop_single_opts()
        )
    ));
}
/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'kimono'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'          => 'font_body',
            'type'        => 'typography',
            'title'       => esc_html__('Body', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'line-height'  => true,
            'font-size'  => true,
            'text-align'  => false,
            'output'      => array('body'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h1',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 1', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h1'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h2',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 2', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h2'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h3',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 3', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h3'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h4',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 4', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h4'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h5',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 5', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h5'),
            'units'       => 'px',
        ),
        array(
            'id'          => 'font_h6',
            'type'        => 'typography',
            'title'       => esc_html__('Heading 6', 'kimono'),
            'google'      => true,
            'font-backup' => true,
            'all_styles'  => true,
            'text-align'  => false,
            'output'      => array('h6'),
            'units'       => 'px',
        ),
    )
));